<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN bật</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN tắt</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Lock Caps on</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Lock Caps off</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Phím số bàn phím on</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Phím số bàn phím off</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad bật</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad tắt</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Chuyển đổi Touchpad</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Chuyển đổi Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Chế độ máy bay bật</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Chế độ máy bay tắt</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Mức năng lượng cân bằng</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Tiết kiệm năng lượng</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Hiệu năng cao</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Hiệu ứng cửa sổ bật</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Hiệu ứng cửa sổ tắt</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Không thể bật hiệu ứng cửa sổ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>